==> haskell-what4-1.6-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-BrOkJe5cD8gG6R85NIelkK
key:                  what4-1.6-BrOkJe5cD8gG6R85NIelkK
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  af0e358e098640336a8dc65c98353ac8
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-BrOkJe5cD8gG6R85NIelkK
depends:
    BoundedChan-1.0.3.0-LpypBc0eid95svZdMy7DB6
    async-2.2.5-6I3Om2iOc9KLV2rb6dASmz
    attoparsec-0.14.4-Kqu9azGoeFY4BlHGbH5HBg base-4.17.2.1
    bifunctors-5.6.2-1uCzk9Zj0rVFyj0BBmHMSQ
    bimap-0.5.0-96r86JMewOiKr2BDjDyx5P
    bv-sized-1.0.6-AMCOVQpV0TMGq5i9nidlZg bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-5ggvRjhQvaeEfCiBwj5xGR
    config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH containers-0.6.7
    deepseq-1.4.8.0 deriving-compat-0.6.7-5BTBnUsuwKTDvO8BpC4jxl
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    fingertree-0.1.6.2-4MFMFPkCVifIkKsaaTXfzI ghc-prim-0.9.1
    hashable-1.4.4.0-EdBgVbn6YIuE9bA3dwmz04
    hashtables-1.4.1-HcTyyBYr5H6JOR107YnGHQ
    io-streams-1.5.2.2-6h9DdiaDLGdKlpSFkhayam
    lens-5.3.1-39Rj9LQQhPID4B1jmyDMFk
    libBF-0.6.6-9KM3GUmMBql5FPwxdMCT5L
    megaparsec-9.7.0-G88a36osNzSFo1446urB6s mtl-2.2.2
    ordered-containers-0.2.4-7ksUL1a20QDCYTnCEROSFM
    panic-0.4.0.1-Jq9VAg5hh1m6c8kWsB4pox
    parameterized-utils-2.1.10.0-GVYcOihYwF6KQgt1t8UnlW parsec-3.1.16.1
    prettyprinter-1.7.1-7LCr279S4u97FneESew6z process-1.6.18.0
    s-cargot-0.1.6.0-64kz8FzzytAAPWfNli2Rft
    scientific-0.3.8.0-5VCcSe8kMhaKTje3aOa6OL stm-2.5.1.0
    template-haskell-2.19.0.0 temporary-1.3-Hhl2LRPiMvQ4xmTU7fPXaD
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-lift-instances-0.1.20-GfwOcACPir1FmwKUeoNubI time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-JjviYpOneZe5nxqbIJEFVH
    unordered-containers-0.2.20-8cMd7edANcDBeBDjVdjsZY
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL
    versions-6.0.8-Jqd2dVZZMCQ9Lli5Gbzbha
    zenc-0.1.2-ElE7vJlNddqF0rScxyqlUi

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-what4-1.6-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-4CNKRHA2OdxKrq4y2dIgM0
key:                  what4-1.6-4CNKRHA2OdxKrq4y2dIgM0
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  ce0c80ef2d9d0805aa6748e573eb2751
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-4CNKRHA2OdxKrq4y2dIgM0
depends:
    BoundedChan-1.0.3.0-LpypBc0eid95svZdMy7DB6
    async-2.2.5-6I3Om2iOc9KLV2rb6dASmz
    attoparsec-0.14.4-Kqu9azGoeFY4BlHGbH5HBg base-4.17.2.1
    bifunctors-5.6.2-1uCzk9Zj0rVFyj0BBmHMSQ
    bimap-0.5.0-96r86JMewOiKr2BDjDyx5P
    bv-sized-1.0.6-BsKeDLjsQV4Fi15J7tE1QR bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-5ggvRjhQvaeEfCiBwj5xGR
    config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH containers-0.6.7
    deepseq-1.4.8.0 deriving-compat-0.6.7-5BTBnUsuwKTDvO8BpC4jxl
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    fingertree-0.1.6.2-4MFMFPkCVifIkKsaaTXfzI ghc-prim-0.9.1
    hashable-1.4.4.0-EdBgVbn6YIuE9bA3dwmz04
    hashtables-1.4.1-HcTyyBYr5H6JOR107YnGHQ
    io-streams-1.5.2.2-6h9DdiaDLGdKlpSFkhayam
    lens-5.3.1-39Rj9LQQhPID4B1jmyDMFk
    libBF-0.6.6-9KM3GUmMBql5FPwxdMCT5L
    megaparsec-9.7.0-G88a36osNzSFo1446urB6s mtl-2.2.2
    ordered-containers-0.2.4-7ksUL1a20QDCYTnCEROSFM
    panic-0.4.0.1-Jq9VAg5hh1m6c8kWsB4pox
    parameterized-utils-2.1.10.0-L7bzXKU8w67D2QeUJgnI8e parsec-3.1.16.1
    prettyprinter-1.7.1-7LCr279S4u97FneESew6z process-1.6.18.0
    s-cargot-0.1.6.0-64kz8FzzytAAPWfNli2Rft
    scientific-0.3.8.0-5VCcSe8kMhaKTje3aOa6OL stm-2.5.1.0
    template-haskell-2.19.0.0 temporary-1.3-Hhl2LRPiMvQ4xmTU7fPXaD
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-lift-instances-0.1.20-GfwOcACPir1FmwKUeoNubI time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-JjviYpOneZe5nxqbIJEFVH
    unordered-containers-0.2.20-8cMd7edANcDBeBDjVdjsZY
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL
    versions-6.0.8-Jqd2dVZZMCQ9Lli5Gbzbha
    zenc-0.1.2-ElE7vJlNddqF0rScxyqlUi

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
